Python API
==========

Cumin Python API autodoc.

.. automodule:: cumin

.. autodata:: __version__

.. rubric:: Subpackages and Submodules

.. toctree::

   cumin.backends
   cumin.color
   cumin.grammar
   cumin.query
   cumin.transport
   cumin.transports
